/***************************************************************************//**
 *   @file   Main.c
 *   @brief  Implementation of the program's main function.
 *   @author Bancisor Mihai
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 560
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRL78G13.h"        // YRDKRL78G13 definitions.
#include "ST7579.h"				// ST7579 definitions.
#include "AD9837.h"             // AD9837 definitions.

/******************************************************************************/
/* Option Bytes                                                               */
/******************************************************************************/
#pragma location = "OPTBYTE"
__root const uint8_t opbyte0 = 0x00U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte1 = 0xFFU;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte2 = 0xE8U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte3 = 0x04U;

/******************************************************************************/
/* Security ID                                                                */
/******************************************************************************/
#pragma location = "SECUID"
__root const uint8_t secuid[10] = 
    {0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U};

/******************************************************************************/
/* Variables Declarations                                                     */
/******************************************************************************/
const unsigned char adiLogo [2 * 19] =
	{ 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x07, 0x07,
	  0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7F, 0x7F,
	  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xC0,
	  0xC0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF8, 0xF8, 0xFC,
	  0xFC, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF };	// ADI Logo.

/***************************************************************************//**
 * @brief Creates a delay of miliseconds.
 *
 * @param mSeconds - time in miliseconds.
 *
 * @return None.
*******************************************************************************/
void DelayMs(unsigned long mSeconds)
{
    unsigned long time = 0;
    
    R_TAU0_Channel0_Start();
    while(time < mSeconds)
    {
        if(TMIF00 == 1)
        {
            time++;
            TMIF00 = 0;
        }
    }
    R_TAU0_Channel0_Stop();
}

/***************************************************************************//**
 * @brief Main function.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void  main(void)
{    
    
    YRDKRL78G13_Init();
    ST7579_Init();
    ST7579_Image(2, 0, adiLogo, 19, 16);
    ST7579_String(2, 21, "ANALOG");
    ST7579_String(3, 21, "DEVICES");
    ST7579_String(4, 0, "wiki.analog.com");
    DelayMs(2000);
    ST7579_Clear();
    ST7579_Image(0,0,adiLogo,19,16);	
    ST7579_String(0,22,"ST7579 OK");
    if(AD9837_Init())
    {
        ST7579_String(1, 22, "AD9837 OK");
    }
    else
    {
        ST7579_String(1 ,22, "AD9837 Err");
    }
	
	AD9837_Reset();
	AD9837_SetFrequency(AD9837_REG_FREQ0, 0x1A37);	// 400 Hz
	AD9837_SetFrequency(AD9837_REG_FREQ1, 0x666666);// 400 kHz
	AD9837_SetPhase(AD9837_REG_PHASE0,0x00);		 
	AD9837_SetPhase(AD9837_REG_PHASE1,0x00);
	AD9837_ClearReset();
	ST7579_String(3,10, "Output signal: ");
	while(1)
	{	
		ST7579_String(4,25, "Sinusoid  ");
		ST7579_String(5, 30, "400 Hz  ");
		AD9837_Setup(AD9837_FSEL0, AD9837_PSEL1, AD9837_OUT_SINUS);
		DelayMs(1000);
       
		ST7579_String(4, 25, "Sinusoid  ");
		ST7579_String(5, 30, "400 kHz   ");
		AD9837_Setup(AD9837_FSEL1, AD9837_PSEL1, AD9837_OUT_SINUS);
		DelayMs(1000);
		ST7579_String(4,25, "Triangle  ");
		ST7579_String(5, 30, "400 Hz  ");
		AD9837_Setup(AD9837_FSEL0, AD9837_PSEL1, AD9837_OUT_TRIANGLE);
		DelayMs(1000);
		ST7579_String(4,25, "Triangle  ");
		ST7579_String(5, 30, "400 kHz  ");
		AD9837_Setup(AD9837_FSEL1, AD9837_PSEL1, AD9837_OUT_TRIANGLE);
		DelayMs(1000);
		ST7579_String(4,25, "Square    ");
		ST7579_String(5, 30, "400 Hz  ");
		AD9837_Setup(AD9837_FSEL0, AD9837_PSEL1, AD9837_OUT_MSB);
		DelayMs(1000);
		ST7579_String(4,25, "Square    ");
		ST7579_String(5, 30, "400 kHz  ");
		AD9837_Setup(AD9837_FSEL1, AD9837_PSEL1, AD9837_OUT_MSB);
		DelayMs(1000);
    }

}

